--TEST--
IBM-DB2: check for connect deallocator functioning to rollback and disconnect if there is any active transaction
--SKIPIF--
<?php require_once('skipif.inc'); ?>
--FILE--
<?php
  require_once('connection.inc');

  // This test case will insert a unique row into the table (primary key column id). and then depending on the case (Autocommit ON/OFF)
  // will try to insert the same row (with same id value) ane expect it to fail or pass accordingly.
  // One cannot use a select statement to retrieve the row with respective id and verify that txn was successful 
  // because no rows does not gaurantee that the txn was rolled back.


  // IN some case db2_exec is prepended with @. This is done to avoid the warnings that will be generated by driver when sql fails, as expected
  //Case1: Check for transaction with Autocommit ON. Autocommit setting triggered from db2_autocommit.
  function case1 () {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    db2_autocommit($conn,DB2_AUTOCOMMIT_ON);

    $stmt = db2_exec($conn,"insert into dealloctab(id, name) values (1, 'case1')");

    if( !$stmt ) {
      echo "case 1 insertion failed\n";
    }
  }

  function verifycase1() {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    $stmt = @db2_exec($conn,"insert into dealloctab(id, name) values (1, 'case1')");

    if( !$stmt ) {
      echo "Test case 1 is successful\n";
    } else {
      echo "Test case 1 failed\n";
    }
  }

   //Case2: Check for transaction with Autocommit OFF. Autocommit setting triggered from db2_autocommit.
  function case2 () {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    db2_autocommit($conn,DB2_AUTOCOMMIT_OFF);

    $stmt = db2_exec($conn,"insert into dealloctab(id, name) values (2, 'case2')");

    if( !$stmt ) {
      echo "case 2 insertion failed\n";
    }
  }

  function verifycase2() {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    $stmt = db2_exec($conn,"insert into dealloctab(id, name) values (2, 'case2')");

    // The insert should have been rolled back hence the above statement should have executed successfully.
    if( $stmt ) {
      echo "Test case 2 is successful\n";
    } else {
      echo "Test case 2 failed\n";
    }

  }

   //Check for transaction with Autocommit ON. Autocommit setting triggered from db2_set_option.

  function case3 () {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);
    $options = array('autocommit' => DB2_AUTOCOMMIT_ON );

    db2_set_option($conn, $options, 1);

    $stmt = db2_exec($conn,"insert into dealloctab(id, name) values (3, 'case3')");

    if( !$stmt ) {
      echo "case 3 insertion failed\n";
    }
  }

  function verifycase3() {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    $stmt = @db2_exec($conn,"insert into dealloctab(id, name) values (3, 'case3')");

    // The insert should have been committed hence the above sql should fail.
	if( !$stmt ) {
      echo "Test case 3 is successful\n";
    } else {
      echo "Test case 3 failed\n";
    }
  }

   //Check for transaction with Autocommit OFF. Autocommit setting triggered from db2_set_option.
  function case4 () {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);
    $options = array('autocommit' => DB2_AUTOCOMMIT_OFF );

    db2_set_option($conn, $options, 1);

    $stmt = db2_exec($conn,"insert into dealloctab(id, name) values (4, 'case4')");

    if( !$stmt ) {
      echo "case 4 insertion failed\n";
    }
  }

  function verifycase4() {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    $stmt = db2_exec($conn,"insert into dealloctab(id, name) values (4, 'case4')");

    // The insert should have been rolled back hence the above statement should execute successfully.
	if( $stmt ) {
      echo "Test case 4 is successful\n";
    } else {
      echo "Test case 4 failed\n";
    }
  }

   //Check for clean transaction with Autocommit OFF. Autocommit setting triggered from db2_set_option.
  function case5 () {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);
    $options = array('autocommit' => DB2_AUTOCOMMIT_OFF );

    db2_set_option($conn, $options, 1);

    $stmt = db2_exec($conn,"insert into dealloctab(id, name) values (5, 'case5')");

    $options1 = array('autocommit' => DB2_AUTOCOMMIT_ON );
    db2_set_option($conn, $options1, 1);

    if( !$stmt ) {
      echo "case 5 insertion failed\n";
    }
  }

  function verifycase5() {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    $stmt = @db2_exec($conn,"insert into dealloctab(id, name) values (5, 'case5')");

    // The insert should have been committed hence the above sql should fail.
	if( !$stmt ) {
      echo "Test case 5 is successful\n";
    } else {
      echo "Test case 5 failed\n";
    }
  }

   //Check for clean transaction with Autocommit OFF. Autocommit setting triggered from db2_autocommit.
  function case6 () {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    db2_autocommit($conn,DB2_AUTOCOMMIT_OFF);

    $stmt = db2_exec($conn,"insert into dealloctab(id, name) values (6, 'case6')");

    db2_autocommit($conn,DB2_AUTOCOMMIT_ON);

    if( !$stmt ) {
      echo "case 6 insertion failed\n";
    }
  }

  function verifycase6() {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    $stmt = @db2_exec($conn,"insert into dealloctab(id, name) values (6, 'case6')");

    // The insert should have been committed hence the above sql should fail.
	if( !$stmt ) {
      echo "Test case 6 is successful\n";
    } else {
      echo "Test case 6 failed\n";
    }
  }

  function prepare() {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    $stmt = db2_exec($conn,"create table dealloctab(id integer primary key not null, name varchar(5))");

    if(!$stmt) {
      echo "Creation of table dealloctab failed \n";
    }
  }

  function cleanup() {
    global $database, $user, $password;

    $conn = db2_connect($database, $user, $password);

    $stmt = db2_exec($conn,"drop table dealloctab");

    if(!$stmt) {
      echo "Dropping of table dealloctab failed \n";
    }
  }

  function main() {
    prepare();
    case1();
    verifycase1();
    case2();
    verifycase2();
    case3();
    verifycase3();
    case4();
    verifycase4();
    /*
    case5();
    verifycase5();
    case6();
    verifycase6();
    */
    cleanup();
  }

  main();
?>
--EXPECT--
Test case 1 is successful
Test case 2 is successful
Test case 3 is successful
Test case 4 is successful
